<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>QtGui::DevView</name>
    <message>
        <location filename="../gui/devview.cpp" line="59"/>
        <source>Copy value</source>
        <translation>Wert kopieren</translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="65"/>
        <source>Copy name</source>
        <translation>Namen kopieren</translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="68"/>
        <source>Copy ID</source>
        <translation>ID kopieren</translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="74"/>
        <source>Resume</source>
        <translation>Fortsetzen</translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="79"/>
        <source>Pause</source>
        <translation>Pausieren</translation>
    </message>
</context>
<context>
    <name>QtGui::DirView</name>
    <message>
        <location filename="../gui/dirview.cpp" line="75"/>
        <source>Copy value</source>
        <translation>Wert kopieren</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="81"/>
        <source>Copy label/ID</source>
        <translation>Namen/ID kopieren</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="84"/>
        <source>Copy path</source>
        <translation>Pfad kopieren</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="89"/>
        <source>Rescan</source>
        <translation>Scannen</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="94"/>
        <source>Resume</source>
        <translation>Fortsetzen</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="99"/>
        <source>Pause</source>
        <translation>Pausieren</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="103"/>
        <source>Open in file browser</source>
        <translation>Im Dateibrowser öffnen</translation>
    </message>
</context>
<context>
    <name>QtGui::DownloadView</name>
    <message>
        <location filename="../gui/downloadview.cpp" line="65"/>
        <source>Copy value</source>
        <translation>Wert kopieren</translation>
    </message>
    <message>
        <location filename="../gui/downloadview.cpp" line="70"/>
        <source>Copy label/ID</source>
        <translation>Namen/ID kopieren</translation>
    </message>
    <message>
        <location filename="../gui/downloadview.cpp" line="74"/>
        <source>Open in file browser</source>
        <translation>Im Dateibrowser öffnen</translation>
    </message>
</context>
<context>
    <name>QtGui::TrayIcon</name>
    <message>
        <location filename="../gui/trayicon.cpp" line="58"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="62"/>
        <source>Rescan all</source>
        <translation>Alle neu scannen</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="70"/>
        <source>Show internal errors</source>
        <translation>Interne Fehler</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="75"/>
        <source>About</source>
        <translation>Über Syncthing Tray</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="80"/>
        <source>Close</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="213"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="233"/>
        <source>Launcher error</source>
        <translation>Starter-Fehler</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="249"/>
        <source>Syncthing notification - click to dismiss</source>
        <translation>Neue Syncthing-Benachrichtigung</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="279"/>
        <source>Syncthing device wants to connect - click for web UI</source>
        <translation>Neues Gerät möchte verbinden</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="295"/>
        <source>New Syncthing folder - click for web UI</source>
        <translation>Neuer Syncthing-Ordner</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="174"/>
        <source>Disconnected from Syncthing</source>
        <translation>Verbindung zu Syncthing getrennt</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="54"/>
        <source>Open Syncthing</source>
        <translation>Syncthing öffnen</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="66"/>
        <source>Log</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QtGui::TrayWidget</name>
    <message>
        <location filename="../gui/traywidget.ui" line="6"/>
        <source>Syncthing Tray</source>
        <translation>Syncthing Tray</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="99"/>
        <location filename="../gui/traywidget.cpp" line="341"/>
        <source>About</source>
        <translation>Über Syncthing Tray</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="58"/>
        <location filename="../gui/traywidget.cpp" line="470"/>
        <source>Connect</source>
        <translation>Verbinden</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="72"/>
        <location filename="../gui/traywidget.cpp" line="844"/>
        <location filename="../gui/traywidget.cpp" line="886"/>
        <source>Start</source>
        <translation>Starten</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="113"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="127"/>
        <source>Open Syncthing</source>
        <translation>Syncthing öffnen</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="289"/>
        <source>In</source>
        <translation>eing.</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="296"/>
        <source>Incoming traffic</source>
        <translation>Eingehender Datenverkehr</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="228"/>
        <location filename="../gui/traywidget.ui" line="248"/>
        <location filename="../gui/traywidget.ui" line="299"/>
        <location filename="../gui/traywidget.ui" line="319"/>
        <source>unknown</source>
        <translation>unbekannt</translation>
    </message>
    <message>
        <source>Pin window</source>
        <translation type="vanished">Offen halten</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="218"/>
        <source>Global</source>
        <translation>Global</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="225"/>
        <source>Global overall statistics</source>
        <translation>Globale Gesamtstatistiken</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="235"/>
        <source>Local</source>
        <translation>Lokal</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="245"/>
        <source>Local overall statistics</source>
        <translation>Lokale Gesamtstatistiken</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="306"/>
        <source>Out</source>
        <translation>ausg.</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="316"/>
        <source>Outgoing traffic</source>
        <translation>Ausgehender Datenverkehr</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="350"/>
        <source>Click to show &lt;i&gt;new&lt;/i&gt; notifications&lt;br&gt;
For &lt;i&gt;all&lt;/i&gt; notifications, checkout the log</source>
        <translation>Klicke um &lt;i&gt;neue&lt;/i&gt; Benachrichtigungen zu zeigen&lt;br&gt;
(für &lt;i&gt;alle&lt;/i&gt; Benachrichtigungen, in den Log schauen)</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="357"/>
        <location filename="../gui/traywidget.cpp" line="155"/>
        <location filename="../gui/traywidget.cpp" line="381"/>
        <source>New notifications</source>
        <translation>Neue Benachrichtigungen</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="388"/>
        <source>Folders</source>
        <translation>Ordner</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="421"/>
        <source>Devices</source>
        <translation>Geräte</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="454"/>
        <source>Downloads</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="483"/>
        <source>Recent changes</source>
        <translatorcomment>&quot;Letzte Änderungen&quot; is too long</translatorcomment>
        <translation>Änderungen</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="519"/>
        <source>Show</source>
        <translation>Zeigen</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="529"/>
        <source>Dismiss</source>
        <translation>Ignorieren</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="127"/>
        <source>View own device ID</source>
        <translation>Eigene Geräte-ID anzeigen</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="132"/>
        <source>Restart Syncthing</source>
        <translation>Syncthing neustarten</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="137"/>
        <source>Show Syncthing log</source>
        <translation>Syncthing-Log zeigen</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="142"/>
        <source>Rescan all folders</source>
        <translation>Alle Ordner neu scannen</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="149"/>
        <source>Connection</source>
        <translation>Verbindung</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="171"/>
        <source>Show internal errors</source>
        <translation>Interne Fehler</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="186"/>
        <source>Quit Syncthing Tray</source>
        <translation>Syncthing Tray schließen</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="438"/>
        <source>Do you really want to restart Syncthing?</source>
        <translation>Soll Syncthing wirklich neu gestartet werden?</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="465"/>
        <source>Connecting …</source>
        <translation>Verbinde …</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="466"/>
        <source>Establishing connection to Syncthing …</source>
        <translation>Stelle Verbindung zu Syncthing her …</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="471"/>
        <source>Not connected to Syncthing, click to connect</source>
        <translation>Verbindung zu Syncthing getrennt, klicke um zu verbinden</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="476"/>
        <source>Unable to establish connection to Syncthing.</source>
        <translation>Verbindung zu Syncthing kann nicht hergestellt werden.</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="484"/>
        <source>Pause</source>
        <translation>Pausieren</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="485"/>
        <source>Syncthing is running, click to pause all devices</source>
        <translation>Syncthing läuft, klicke um alle Geräte zu pausieren</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="490"/>
        <source>Continue</source>
        <translation>Fortsetzen</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="491"/>
        <source>At least one device is paused, click to resume</source>
        <translation>Mind. ein Gerät ist pausiert, klicke um fortzusetzen</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="614"/>
        <source>The specified connection configuration &lt;em&gt;%1&lt;/em&gt; is not defined and hence ignored.</source>
        <translation>Die angegebene Verbindungskonfiguration &lt;em&gt;%1&lt;/em&gt; ist nicht definiert und wird daher ignoriert.</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="666"/>
        <source>The folder &lt;i&gt;%1&lt;/i&gt; does not exist on the local machine.</source>
        <translation>Der Ordner &lt;i&gt;%1&lt;/i&gt; existiert nicht lokal.</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="677"/>
        <source>The containing folder &lt;i&gt;%1&lt;/i&gt; does not exist on the local machine.</source>
        <translation>Der beinhaltende Ordner &lt;i&gt;%1&lt;/i&gt; existiert nicht lokal.</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="720"/>
        <source>Copy path</source>
        <translation>Pfad kopieren</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="724"/>
        <source>Copy device ID</source>
        <translation>Geräte-ID kopieren</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="727"/>
        <source>Copy folder ID</source>
        <translation>Ordner-ID kopieren</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="840"/>
        <location filename="../gui/traywidget.cpp" line="880"/>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="841"/>
        <source>Stop Syncthing instance launched via tray icon</source>
        <translation>Stoppe Syncthing-Instanz, die mit dem internen Starter gestartet wurde</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="845"/>
        <source>Start Syncthing with the built-in launcher configured in the settings</source>
        <translation>Starte Syncthing mit dem eingebauten Starter, der in den Einstellungen konfiguriert wird</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../application/main.cpp" line="61"/>
        <source>Unable to </source>
        <translation>Fehler beim </translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="96"/>
        <source>The system tray is (currently) not available. You could open the tray menu as a regular window using the --windowed flag, though.It is also possible to start Syncthing Tray with --wait to wait until the system tray becomes available instead of showing this message.</source>
        <translation>Das System-Tray bzw. der Infobereich ist aktuell nicht verfügbar. Mit der Option &quot;--windowed&quot; ist es möglich, Syncthing Tray als normales Fenster zu starten. Außerdem ist es möglich mit der Option &quot;--wait&quot; zu warten bis das System-Tray verfügbar ist anstelle diesen Dialog zu zeigen.</translation>
    </message>
    <message>
        <source>You must configure how to connect to Syncthing when using Syncthing Tray the first time.</source>
        <translation type="vanished">Vor der ersten Verwendung muss eingestellt werden, wie sich das Syncthing Tray mit Syncthing verbinden soll.</translation>
    </message>
    <message>
        <source>Note that the settings dialog allows importing URL, credentials and API-key from the local Syncthing configuration.</source>
        <translation type="vanished">Der Einstellungsdialog ermöglicht es die URL, Zugangsdaten und den API-Key automatisch aus der lokalen Syncthing-Konfiguration auszulesen.</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="123"/>
        <source>The Qt libraries have not been built with tray icon support. You could open the tray menu as a regular window using the -w flag, though.</source>
        <translation>Die verwendete Qt-Bibliothek wurde nicht mit Unterstützung für System-Tray konfiguriert. Es wäre möglich, Syncthing Tray als normales Fenster zu starten (mit Option -w).</translation>
    </message>
</context>
</TS>
